﻿
using System.Collections;
using System.Collections.Generic;
using UnityEngine;


public class CarScript : MonoBehaviour
{

    // Movement Variables
    public Vector3 movement;
    public float zMovement;
    public float movementSpeed;
    public float turnSpeed = 2.5f;
    public bool enteredCar = false;
    Vector3 euler;

    // Variables for entering the car in OnTriggerEnter
    [SerializeField]
    private float coolDown;
    [SerializeField]
    private CameraScript cam;
    private Rigidbody rigBody;

    private float enterTimeStamp = 0;

    private PlayerScript currentPlayer;
    private bool curFrame;

    void Update()
    {
        // Make sure the player can only drive the car once he/she enters the car
        if (enteredCar == true)
            HandleMovement();
    }

    void HandleMovement()
    {
        // Set both X and Y constraints on rigidbody
        rigBody.constraints = RigidbodyConstraints.FreezeRotationX | RigidbodyConstraints.FreezeRotationZ;


        zMovement = movementSpeed * Input.GetAxis("Vertical" + +currentPlayer.playerNumber);

        movement = new Vector3(0, rigBody.velocity.y, zMovement);


        if (zMovement != 0)
        {
            Vector3 origPos = cam.transform.position;
            cam.transform.position = Vector3.Scale(cam.transform.forward, new Vector3(1, 0, 1).normalized);
            movement = zMovement * cam.transform.position;
            cam.transform.position = origPos;
        }

        movement.Normalize();
        movement *= movementSpeed;
        movement.y = rigBody.velocity.y;
        rigBody.velocity = movement;

        transform.rotation = Quaternion.Euler(transform.rotation.x, cam.xRotation, transform.rotation.z);
        

        // If the player IS in the car, revert everything
        if (Input.GetButtonDown("Vehicle" + currentPlayer.playerNumber) && enteredCar == true && !curFrame)
        {
            currentPlayer.transform.SetParent(null);
            currentPlayer.transform.localScale = Vector3.one;

            currentPlayer.GetComponent<Rigidbody>().useGravity = true;
            currentPlayer.GetComponent<Rigidbody>().isKinematic = false;

            SkinnedMeshRenderer[] childMeshes = currentPlayer.GetComponentsInChildren<SkinnedMeshRenderer>();

            foreach (SkinnedMeshRenderer mesh in childMeshes)
                mesh.enabled = true;

            cam.target = currentPlayer.transform;
            currentPlayer.GetComponent<MovementControl>().enabled = true;
            rigBody.isKinematic = true;
            //rigBody = GetComponent<Rigidbody>();
            //Destroy(rigBody);
            enteredCar = false;
        }

        curFrame = false;
    }

    private void OnTriggerStay(Collider other)
    {
        if (other.tag == "Player")
        {
            if (Time.realtimeSinceStartup - enterTimeStamp > coolDown)
            {
                // The array containing all child meshes. We use this array to disable all visuals in the object's children
                SkinnedMeshRenderer[] childMeshes = other.GetComponentsInChildren<SkinnedMeshRenderer>();

                currentPlayer = other.gameObject.GetComponent<PlayerScript>();

                // If the player has not entered the car, disable all visuals, stop physics, and make it a trigger to stop collision
                // while still detecting if it's still in THIS trigger
                if (Input.GetButtonDown("Vehicle" + currentPlayer.playerNumber) && enteredCar == false)
                {
                    ObjectManager.objectManager.UseItem(gameObject, currentPlayer.playerNumber);

                    other.transform.SetParent(transform);

                    other.GetComponent<Rigidbody>().isKinematic = true;
                    other.GetComponent<Rigidbody>().useGravity = false;
                    //other.isTrigger = true;

                    foreach (SkinnedMeshRenderer mesh in childMeshes)
                        mesh.enabled = false;

                    cam.target = gameObject.transform;
                    other.GetComponent<MovementControl>().enabled = false;
                    rigBody = GetComponent<Rigidbody>();
                    if (rigBody == null)
                        rigBody = gameObject.AddComponent<Rigidbody>();

                    rigBody.isKinematic = false;
                    enteredCar = true;
                    curFrame = true;

                }
            }
        }
    }
}

