﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class Interactable : MonoBehaviour
{
    public ToDoList.ToDoListItem myToDoItem;

    public int points;
    public float completeTime;
    public float rottenTime;

    protected PlayerScript playerInteracted;

    public GameObject cameraToLookAt;

    public Text itemTypeImg;
    public GameObject timerParent;
    public Image timerVisuals;

    protected bool timerStarted;
    protected bool timedDone;
    protected bool otherUsed = false;

    public string completeString = "";

    protected string origString;

    protected string aButton = "";
    protected string yButton = "";
    protected string bButton = "";
    protected string xButton = "";
    protected List<string> buttonStrings = new List<string>();

    protected virtual void Start()
    {
        buttonStrings.Add(aButton);
        buttonStrings.Add(bButton);
        buttonStrings.Add(xButton);
        buttonStrings.Add(yButton);

        origString = itemTypeImg.text;
        timerParent.GetComponent<RectTransform>().localPosition = new Vector3(0, 5, 0);
    }

    public virtual void Interact(PlayerScript aPlayer)
    {
        if (otherUsed)
            return;

        if (!timerStarted)
        {
            timerStarted = true;

            ObjectManager.objectManager.UseItem(this, aPlayer.playerNumber);

            playerInteracted = aPlayer;
            Debug.Log("Started " + myToDoItem + " for player " + aPlayer.playerNumber + "!");
            StartCoroutine(TimedInteraction(completeTime));
        }
        else if (timedDone)
        {
            aPlayer.CompleteItem(myToDoItem, points);
            itemTypeImg.text = completeString;
            itemTypeImg.gameObject.SetActive(true);
            timerParent.SetActive(false);
            //gameObject.SetActive(false);
        }
    }

    protected virtual void Update()
    {
        if (cameraToLookAt != null)
        {
            itemTypeImg.transform.parent.LookAt((cameraToLookAt.transform.position - itemTypeImg.transform.parent.position) * 100);
        }
    }

    IEnumerator TimedInteraction(float aTime)
    {
        float startTime = Time.time;

        //itemTypeImg.gameObject.SetActive(false);
        timerParent.SetActive(true);

        while (Time.time - startTime < aTime)
        {
            timerVisuals.GetComponent<RectTransform>().localPosition = new Vector3(0, Mathf.Lerp(-100, 0, Mathf.Abs(Time.time - startTime) / aTime), 0);
            yield return new WaitForEndOfFrame();
        }

        Debug.Log("Done " + myToDoItem + " for player " + playerInteracted.playerNumber + "!");

        timedDone = true;

        float completedTime = Time.time;
        Color startingColor = timerVisuals.color;

        while (true)
        {
            timerVisuals.color = Color.Lerp(startingColor, Color.red, (Time.time - completedTime) / rottenTime);
            yield return new WaitForEndOfFrame();
        }
    }

    public void TurnOff()
    {
        otherUsed = true;
        timerParent.GetComponent<Image>().color = new Color((30f / 255f), (30f / 255f), (30f / 255f), .5f);
    }
}