﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class MovementControl : MonoBehaviour
{
    [SerializeField]
    private float movementSpeed = 5;
    [SerializeField]
    private float rotationSpeed = 5;
    [SerializeField]
    private bool smoothRotations;
    [SerializeField]
    private CameraScript cam;
    [SerializeField]
    private Animator myAnim;

    private float xMovement;
    private float zMovement;
    private Vector3 movement;
    private Rigidbody rigBody;

    public PlayerScript myPlayerScript;

    // Initialize any variables
    void Start()
    {
        rigBody = GetComponent<Rigidbody>();
    }

    // Make the player move
    void FixedUpdate()
    {
        xMovement = movementSpeed * Input.GetAxis("Horizontal" + myPlayerScript.playerNumber);
        zMovement = movementSpeed * Input.GetAxis("Vertical" + myPlayerScript.playerNumber);

        movement = new Vector3(xMovement, rigBody.velocity.y, zMovement);

        // Prevent the rotation from resetting when we stop moving
        if (xMovement != 0 || zMovement != 0)
        {
            cam.transform.position = Vector3.Scale(cam.transform.forward, new Vector3(1, 0, 1).normalized);
            movement = zMovement * cam.transform.position + xMovement * cam.transform.right;

            Quaternion newRotation = Quaternion.LookRotation(movement);

            if (rigBody.isKinematic == false)
            {
                if (smoothRotations == true)
                    // Add smoothness to rotation
                    transform.rotation = Quaternion.RotateTowards(transform.rotation, newRotation, rotationSpeed);
                else
                    // Make the rotation "pop"
                    transform.rotation = newRotation;
            }
        }

        // Normalize movement to make sure the player's diagonal movement doesn't make it go faster
        movement.Normalize();
        movement *= movementSpeed;

        if(myAnim != null && rigBody.isKinematic == false && (movement.z != 0 || movement.x != 0))
            myAnim.SetFloat("Forward", 1);
        else
        {
            myAnim.SetFloat("Forward", 0);
        }

        movement.y = rigBody.velocity.y;

        rigBody.velocity = movement;
    }

    public void StopRunning()
    {
        myAnim.SetFloat("Forward", 0);
    }

    public void DoAnim(int aVal, bool aSuccess)
    {
        if (aSuccess)
        {
            myAnim.SetTrigger("Grab" + aVal);
        }
        else
        {
            myAnim.SetTrigger("Fail" + aVal);
        }
    }

    public void ResetAllTriggers()
    {
        for(int i = 0; i < 3; i++)
        {
            myAnim.ResetTrigger("Grab" + i);
            myAnim.ResetTrigger("Fail" + i);
        }

        myAnim.ResetTrigger("Fail" + 3);
    }
}
