﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ObjectManager : MonoBehaviour
{
    public static ObjectManager objectManager;

    public List<ObjectPair> objPairs = new List<ObjectPair>();

    public List<VehiclePair> vehPair = new List<VehiclePair>();

    private Dictionary<ToDoList.ToDoListItem, List<ObjectPair>> objDict = new Dictionary<ToDoList.ToDoListItem, List<ObjectPair>>();

    void Awake()
    {
        objectManager = this;

        foreach (ObjectPair op in objPairs)
        {
            if (objDict.ContainsKey(op.itemType))
            {
                objDict[op.itemType].Add(op);
            }
            else
            {
                List<ObjectPair> tempList = new List<ObjectPair>();
                tempList.Add(op);
                objDict.Add(op.itemType, tempList);
            }
        }
    }

    public void UseItem(Interactable aItem, int aPlayerNumber)
    {
        foreach (ObjectPair op in objDict[aItem.myToDoItem])
        {
            if (op.pairedObjects[aPlayerNumber] == aItem)
            {
                if (op.pairedObjects[(aPlayerNumber + 1) % 2] != null)
                    op.pairedObjects[(aPlayerNumber + 1) % 2].gameObject.SetActive(false);
            }
            else
            {
                op.pairedObjects[aPlayerNumber].TurnOff();
            }
        }
        /*
        for(int i = 0; i < objPairs.Count; i++)
        {
            if(objPairs[i].pairedObjects[aPlayerNumber] == aItem)
            {          
                objPairs[i].pairedObjects[(aPlayerNumber + 1) % 2].SetActive(false);
            }
        }
        */
    }

    public void UseItem(GameObject aItem, int aPlayerNumber)
    {
        foreach (VehiclePair vp in vehPair)
        {
            if (vp.pairedObjects[aPlayerNumber] == aItem)
                if (vp.pairedObjects[(aPlayerNumber + 1) % 2] != null)
                    vp.pairedObjects[(aPlayerNumber + 1) % 2].gameObject.SetActive(false);
        }
    }
}

[System.Serializable]
public class ObjectPair
{
    public string name;
    public ToDoList.ToDoListItem itemType;
    public List<Interactable> pairedObjects;
}

[System.Serializable]
public class VehiclePair
{
    public string name;
    public List<GameObject> pairedObjects;
}