﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class PlayerScript : MonoBehaviour
{
    public int playerNumber;

    public ToDoList myToDoList;

    public Interactable itemToUse;

    private List<ScoreItem> score = new List<ScoreItem>();

    public bool hasLeash = false;

    public GameObject toDoParent;
    public GameObject scoreParent;

    public List<Text> scoreTexts;
    private Dictionary<ToDoList.ToDoListItem, Text> dictScoreText = new Dictionary<ToDoList.ToDoListItem, Text>();

    private float startTime;

    public Transform awakePos;

    public Text itemTypeImg;
    public Image timerVisuals;
    private int QTEMax;
    private int QTECur;
    float lastQTE = 0;
    float nextQTE;
    int selectedButton;
    bool haveQTE = false;

    protected string aButton = "";
    protected string yButton = "";
    protected string bButton = "";
    protected string xButton = "";
    protected List<string> buttonStrings = new List<string>();

    private bool awake;

    void Start()
    {
        buttonStrings.Add(aButton);
        buttonStrings.Add(bButton);
        buttonStrings.Add(xButton);
        buttonStrings.Add(yButton);

        startTime = Time.time;

        QTEMax = 10;

        for (int i = 0; i < 6; i++)
        {
            dictScoreText.Add((ToDoList.ToDoListItem)i, scoreTexts[i]);
        }
    }

    void Update()
    {
        if (itemToUse != null && Input.GetButtonDown("Use"+playerNumber))
        {
            InteractWithItem();
        }

        if (!awake)
        {
            if (haveQTE)
            {
                if (Input.GetButtonDown("QTE" + selectedButton + playerNumber))
                {
                    GetComponent<MovementControl>().DoAnim(Random.Range(0, 3), true);
                    QTECur++;
                    //curPercentVal += nextQTE;
                    //itemTypeImg.text = "";
                    NextQTE();
                }
                else if (Input.GetButtonDown("QTE" + ((selectedButton + 1) % 4) + playerNumber))
                {
                    haveQTE = false;
                    GetComponent<MovementControl>().DoAnim(Random.Range(0, 4), false);
                    QTECur--;
                    lastQTE = Time.time;
                    nextQTE = 2;
                    //curPercentVal -= nextQTE;
                    itemTypeImg.text = "";
                }
                else if (Input.GetButtonDown("QTE" + ((selectedButton + 2) % 4) + playerNumber))
                {
                    haveQTE = false;
                    GetComponent<MovementControl>().DoAnim(Random.Range(0, 4), false);
                    QTECur--;
                    lastQTE = Time.time;
                    nextQTE = 2;
                    //curPercentVal -= nextQTE;
                    itemTypeImg.text = "";
                }
                else if (Input.GetButtonDown("QTE" + ((selectedButton + 3) % 4) + playerNumber))
                {
                    haveQTE = false;
                    GetComponent<MovementControl>().DoAnim(Random.Range(0, 4), false);
                    QTECur--;
                    lastQTE = Time.time;
                    nextQTE = 2;
                    //curPercentVal -= nextQTE;
                    itemTypeImg.text = "";
                }

                if (QTECur >= QTEMax)
                {
                    awake = true;
                    iTween.MoveTo(gameObject, iTween.Hash("position", awakePos.position, "time", 1, "easetyep", iTween.EaseType.easeInOutSine, "oncompletetarget", gameObject, "oncomplete", "DoneAwake"));
                    //iTween.RotateTo(gameObject, iTween.Hash("rotation", awakePos.rotation, "time", 1, "easetyep", iTween.EaseType.easeInOutSine));
                    GetComponent<MovementControl>().ResetAllTriggers();
                    timerVisuals.transform.parent.gameObject.SetActive(false);
                    itemTypeImg.text = "";
                }
            }

            timerVisuals.GetComponent<RectTransform>().localPosition = new Vector3(0, Mathf.Lerp(-100, 0, ((float)QTECur) / ((float)QTEMax)), 0);

            if (!haveQTE && Time.time - lastQTE > nextQTE)
            {
                lastQTE = Time.time;
                //nextQTE = 5;//Random.Range(4f, 5f);
                haveQTE = true;
                selectedButton = Random.Range(0, 4);

                itemTypeImg.text = buttonStrings[selectedButton];
            }
        }
    }

    public void DoneAwake()
    {
        GetComponent<Rigidbody>().isKinematic = false;
    }

    void InteractWithItem()
    {
        itemToUse.Interact(this);
    }

    public void CompleteItem(ToDoList.ToDoListItem aItem, int aPointVal)
    {
        ScoreItem si = new ScoreItem();

        si.itemType = aItem;
        si.scoreVal = aPointVal;

        score.Add(si);

        myToDoList.CompleteItem(aItem);
    }

    public void GotToWork()
    {
        float finishTime = Time.time;

        toDoParent.SetActive(false);
        scoreParent.SetActive(true);
        GetComponent<Rigidbody>().isKinematic = true;

        float total = 0;
        foreach(ScoreItem si in score)
        {
            total += si.scoreVal;
            dictScoreText[si.itemType].text = si.scoreVal.ToString();
        }
        /*
        for(int i = 0; i < score.Count; i++)
        {
            total += score[i].scoreVal;
            scoreTexts[i].text = score[i].scoreVal.ToString();
        }
        */
        float timeVal = Mathf.FloorToInt(600 - (finishTime - startTime) * 5);
        total += timeVal;

        scoreTexts[scoreTexts.Count - 2].text = timeVal.ToString();
        scoreTexts[scoreTexts.Count - 1].text = total.ToString();
    }

    private void NextQTE()
    {
        selectedButton = Random.Range(0, 4);

        itemTypeImg.text = buttonStrings[selectedButton];

        lastQTE = Time.time;
    }
}

public class ScoreItem
{
    public ToDoList.ToDoListItem itemType;
    public int scoreVal;
}