﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Skateboard : MonoBehaviour
{

    private float xMovement;
    private Vector3 movement;
    private Rigidbody rigBody;
    private SkateJump skateJump;
    [HideInInspector]
    public float zMovement;
    [SerializeField]
    private float movementSpeed;
    [SerializeField]
    private float turnSpeed;
    [SerializeField]
    private CameraScript cam;
    [SerializeField]
    private bool riding = false;
    [SerializeField]
    private Transform playerSpot;
    [SerializeField]
    private float jumpPower = 5.0f;

    PlayerScript currentPlayer;

    void Start()
    {
        skateJump = GetComponentInChildren<SkateJump>();
    }

    void Update()
    {
        if (riding == true)
            HandleMovement();
    }


    void HandleMovement()
    {
        // Constrain rotations on rigidbody
        rigBody.constraints = RigidbodyConstraints.FreezeRotation;

        xMovement = movementSpeed * Input.GetAxis("Horizontal" + currentPlayer.playerNumber);
        zMovement = movementSpeed * Input.GetAxis("Vertical" + currentPlayer.playerNumber);

        if (zMovement == 0)
            xMovement = 0;

        movement = new Vector3(xMovement, rigBody.velocity.y, zMovement);

        if (xMovement != 0 || zMovement != 0)
        {
            Vector3 origPos = cam.transform.position;

            cam.transform.position = Vector3.Scale(cam.transform.forward, new Vector3(1, 0, 1).normalized);
            movement = zMovement * cam.transform.position + xMovement * cam.transform.right;

            Quaternion newRotation = Quaternion.LookRotation(movement);
            transform.rotation = Quaternion.RotateTowards(transform.rotation, newRotation, turnSpeed);

            cam.transform.position = origPos;
        }

        movement.Normalize();
        movement *= movementSpeed;
        movement.y = rigBody.velocity.y;

        if (skateJump.jump == true)
            HandleJumping();
        rigBody.velocity = movement;
    }

    void HandleJumping()
    {
        if (Input.GetButtonDown("Jump" + currentPlayer.playerNumber))
        {
            movement.y += jumpPower;
            skateJump.jump = true;
        }
    }

    void OnTriggerStay(Collider other)
    {
        if (other.tag == "Player")
        {
            currentPlayer = other.GetComponent<PlayerScript>();
            if (Input.GetButtonDown("Vehicle" + currentPlayer.playerNumber) && riding == false)
            {
                ObjectManager.objectManager.UseItem(gameObject, currentPlayer.playerNumber);

                //Vector3 origScale = other.transform.localScale;
                other.transform.SetParent(playerSpot);
                other.transform.localPosition = playerSpot.localPosition;
                other.transform.localRotation = Quaternion.identity;
                other.transform.localScale = playerSpot.lossyScale;
                other.GetComponent<MovementControl>().enabled = false;

                other.GetComponent<Rigidbody>().isKinematic = true;
                other.GetComponent<Rigidbody>().useGravity = false;
                other.isTrigger = true;

                cam.target = transform;
                rigBody = GetComponent<Rigidbody>();
                if (rigBody == null)
                    rigBody = gameObject.AddComponent<Rigidbody>();
                rigBody.isKinematic = false;

                other.GetComponent<MovementControl>().StopRunning();

                riding = true;
            }
            else if (Input.GetButtonDown("Vehicle" + currentPlayer.playerNumber) && riding == true)
            {
                other.transform.SetParent(null);
                other.transform.localScale = Vector3.one;

                other.GetComponent<Rigidbody>().useGravity = true;
                other.GetComponent<Rigidbody>().isKinematic = false;
                other.isTrigger = false;

                cam.target = other.transform;
                other.GetComponent<MovementControl>().enabled = true;
                rigBody.isKinematic = true;
                //rigBody = GetComponent<Rigidbody>();
                //Destroy(rigBody);
                riding = false;
            }
        }
    }
}
